#cheese

class Variables:
    release = "1.2.18"
    documentation = "https://kubaboi.github.io/CheeseFramework/"
